import {
  Box,
  Flex,
  Heading,
  Text,
  Stack,
  Divider,
  Icon,
  Image,
  useColorModeValue,
} from '@chakra-ui/react';
import { ArrowUpRight } from 'lucide-react';

export default function SubHeroSection() {
  // Define data for each card
  const cards = [
    {
      image: '/images/icon1.png',
      title: 'Real Story Update #1',
      description: 'Hear from individuals who’ve walked through adversity and growth, sharing true life lessons that matter.',
    },
    {
      image: '/images/icon2.png',
      title: 'Real Story Update #2',
      description: 'Discover insights and personal journeys that inspire transformation and resilience.',
    },
    {
      image: '/images/icon3.png',
      title: 'Real Story Update #3',
      description: 'Explore real accounts of overcoming hardship and emerging stronger than ever.',
    },
  ];

  return (
    <Box
      bg={useColorModeValue('gray.50', '#1A1A1A')}
      px={{ base: 4, md: 12 }}
      py={{ base: 10, md: 20 }}
    >
      <Divider mb={12} borderColor={useColorModeValue('gray.300', 'gray.700')} />

      <Flex direction={{ base: 'column', md: 'row' }} gap={12}>
        {/* Right Section - Three Cards */}
        <Flex flex={1} direction={{ base: 'column', md: 'row' }} gap={6}>
          {cards.map((card, i) => (
            <Box
              key={i}
              flex={1}
              bg={useColorModeValue('white', '#2D2D2D')}
              borderRadius="lg"
              boxShadow="sm"
              p={6}
              position="relative"
              transition="all 0.3s ease"
              _hover={{ boxShadow: 'md', transform: 'translateY(-2px)' }}
            >
              <Box mb={4}>
                <Image
                  src={card.image}
                  alt="News Icon"
                  boxSize="40px"
                  objectFit="contain"
                />
              </Box>

              <Heading fontSize="lg" mb={2} color={useColorModeValue('gray.800', 'gray.100')}>
                {card.title}
              </Heading>
              <Text fontSize="sm" color={useColorModeValue('gray.600', 'gray.400')} noOfLines={3}>
                {card.description}
              </Text>

              <Box position="absolute" right={4} top="50%" transform="translateY(-50%)">
                <Icon as={ArrowUpRight} boxSize={6} color="teal.500" cursor="pointer" />
              </Box>
            </Box>
          ))}
        </Flex>
      </Flex>
    </Box>
  );
}
